@@ -26,6 +26,37 @@ describe OmniAuth::Strategies::Twitter do
     end
   end
 
+  describe 'info' do
+    before do
+      allow(subject).to receive(:raw_info).and_return(raw_info_hash)
+    end
+
+    it 'should returns the nickname' do
+      expect(subject.info[:nickname]).to eq(raw_info_hash['screen_name'])
+    end
+
+    it 'should returns the name' do
+      expect(subject.info[:name]).to eq(raw_info_hash['name'])
+    end
+
+    it 'should returns the email' do
+      expect(subject.info[:email]).to eq(raw_info_hash['email'])
+    end
+
+    it 'should returns the location' do
+      expect(subject.info[:location]).to eq(raw_info_hash['location'])
+    end
+
+    it 'should returns the description' do
+      expect(subject.info[:description]).to eq(raw_info_hash['description'])
+    end
+
+    it 'should returns the urls' do
+      expect(subject.info[:urls]['Website']).to eq(raw_info_hash['url'])
+      expect(subject.info[:urls]['Twitter']).to eq("https://twitter.com/#{raw_info_hash['screen_name']}")
+    end
+  end
+
   describe 'image_size option' do
     context 'when user has an image' do
       it 'should return image with size specified' do
@@ -99,6 +130,48 @@ describe OmniAuth::Strategies::Twitter do
       end
     end
 
+    context 'with a specified callback_url in the params' do
+      before do
+        params = { 'callback_url' => 'http://foo.dev/auth/twitter/foobar' }
+        allow(subject).to receive(:request) do
+          double('Request', :params => params)
+        end
+        allow(subject).to receive(:session) do
+          double('Session', :[] => { 'callback_url' => params['callback_url'] })
+        end
+        allow(subject).to receive(:old_request_phase) { :whatever }
+      end
+
+      it 'should use the callback_url' do
+        expect(subject.callback_url).to eq 'http://foo.dev/auth/twitter/foobar'
+      end
+
+      it 'should return the correct callback_path' do
+        expect(subject.callback_path).to eq '/auth/twitter/foobar'
+      end
+    end
+
+    context 'with no callback_url set' do
+      before do
+        allow(subject).to receive(:request) do
+          double('Request', :params => {})
+        end
+        allow(subject).to receive(:session) do
+          double('Session', :[] => {})
+        end
+        allow(subject).to receive(:old_request_phase) { :whatever }
+        allow(subject).to receive(:old_callback_url).and_return(:old_callback)
+      end
+
+      it 'callback_url should return nil' do
+        expect(subject.callback_url).to eq :old_callback
+      end
+
+      it 'should return the default callback_path value' do
+        expect(subject.callback_path).to eq '/auth/twitter/callback'
+      end
+    end
+
     context "with no request params set and force_login specified" do
       before do
         allow(subject).to receive(:request) do
@@ -113,3 +186,16 @@ describe OmniAuth::Strategies::Twitter do
     end
   end
 end
+
+private
+
+def raw_info_hash
+  {
+    'screen_name' => 'foo',
+    'name' => 'Foo Bar',
+    'email' => 'foo@example.com',
+    'location' => 'India',
+    'description' => 'Developer',
+    'url' => 'example.com/foobar'
+  }
+end
